@@ -303,12 +303,11 @@ def create_compiled_operators_metadata() -> None:
         json.dump(compiled_metadata, f, indent=4)
 
 
-def create_dependencies_map(repo_name: str, save_map_as_file: bool = True) -> None:
+def create_dependencies_map(save_map_as_file: bool = True) -> None:
     """
     Construct a map between Operators and unique definitions for docker images dependencies
 
     Args:
-        repo_name (str): Name of the repository, as defined in config.toml
         save_map_as_file (bool, optional): Set if dependencies_map will be saved as file. Defaults to True.
 
     Raises:
@@ -328,7 +327,7 @@ def create_dependencies_map(repo_name: str, save_map_as_file: bool = True) -> No
 
         if op_i == 0:
             operators_images_map = {
-                f"{repo_name}_image_0": {
+                f"group0": {
                     "dependency": operator_metadata["dependency"],
                     "operators": [operator_name],
                     "secrets": operator_secrets
@@ -345,7 +344,7 @@ def create_dependencies_map(repo_name: str, save_map_as_file: bool = True) -> No
                     skip_new_image = True
                     continue
             if not skip_new_image:
-                operators_images_map[f"{repo_name}_image_{len(existing_keys)}"] = {
+                operators_images_map[f"group{len(existing_keys)}"] = {
                     "dependency": operator_metadata["dependency"],
                     "operators": [operator_name],
                     "secrets": operator_secrets
@@ -371,6 +370,16 @@ def build_docker_images(publish_images: bool) -> None:
     return updated_dependencies_map
 
 
+def validate_repo_name(repo_name: str) -> None:
+    """
+    Validate repository name
+    """
+    if any([a.isspace() for a in repo_name]):
+        raise ValueError("Repository name should not contain blank spaces")
+    if any([a in repo_name for a in ["!", "@", "#", "$", "%", "^", "&", "*", "(", ")", "+", "=", "{", "}", "[", "]", ":", ";", "'", '"', "<", ">", "?", "/", "\\", "|", "~", "`"]]):
+        raise ValueError("Repository name should not contain special characters")
+
+
 def organize_operators_repository(build_images: bool, publish_images: bool) -> None:
     """
     Organize Operator's repository for FlowUI. This will: 
@@ -388,15 +397,13 @@ def organize_operators_repository(build_images: bool, publish_images: bool) -> N
     with open("config.toml", "rb") as f:
         repo_config = tomli.load(f)
     repo_name = repo_config["repository"]["REPOSITORY_NAME"]
+    validate_repo_name(repo_name)
     
     # Create compiled metadata from Operators metadata.json files and add data input schema
     create_compiled_operators_metadata()
     
     # Generate dependencies_map.json file
-    create_dependencies_map(
-        repo_name=repo_name,
-        save_map_as_file=True
-    )
+    create_dependencies_map(save_map_as_file=True)
     console.print("Metadata and dependencies organized successfully!", style=f"bold {COLOR_PALETTE.get('success')}")
 
     # Build and publish the images
