@@ -130,7 +130,7 @@ def create_platform(flowui_frontend_image: str = None, flowui_backend_image: str
                     propagation='HostToContainer'
                 )
             )
-        if flowui_config['local_flowui_repository']['FLOWUI_LOCAL_FLOWUI_REPOSITORY']:
+        if flowui_config['local_flowui_repository'].get('FLOWUI_LOCAL_FLOWUI_REPOSITORY'):
             extra_mounts_local_repositories.append(
                 dict(
                     hostPath=flowui_config['local_flowui_repository']['FLOWUI_LOCAL_FLOWUI_REPOSITORY'],
@@ -268,9 +268,10 @@ def create_platform(flowui_frontend_image: str = None, flowui_backend_image: str
     )
     airflow_ssh_config_parsed = AsLiteral(yaml.dump(airflow_ssh_config))
 
-    workers_extra_volumes = {}
-    workers_extra_volumes_mounts = {}
-    if flowui_config['kind']["dev_mode"] == 'local' and flowui_config['local_flowui_repository']['FLOWUI_LOCAL_FLOWUI_REPOSITORY']:
+    workers_extra_volumes = []
+    workers_extra_volumes_mounts = []
+    workers = {}
+    if flowui_config['kind']["dev_mode"] == 'local' and flowui_config['local_flowui_repository'].get('FLOWUI_LOCAL_FLOWUI_REPOSITORY'):
         workers_extra_volumes = [
             {
                 "name": "flowui-dev-extra",
@@ -285,6 +286,12 @@ def create_platform(flowui_frontend_image: str = None, flowui_backend_image: str
                 "mountPath": "/opt/airflow/flowui_dev"
             }
         ]
+        workers = {
+            "workers": {
+                "extraVolumes": workers_extra_volumes,
+                "extraVolumeMounts": workers_extra_volumes_mounts,
+            }
+        }
 
     airflow_values_override_config = {
         "airflow": {
@@ -318,10 +325,7 @@ def create_platform(flowui_frontend_image: str = None, flowui_backend_image: str
                     "sshKeySecret": "airflow-ssh-secret"
                 }
             },
-            "workers": {
-                "extraVolumes": workers_extra_volumes,
-                "extraVolumeMounts": workers_extra_volumes_mounts,
-            }
+            **workers
         }
     }
 
@@ -343,10 +347,53 @@ def create_platform(flowui_frontend_image: str = None, flowui_backend_image: str
 
     # For each path create a pv and pvc
     if flowui_config['kind']['dev_mode'] == 'local':
-        console.print("Creating PV's and PVC's for Local Development mode\n")
         config.load_kube_config()
         k8s_client = client.CoreV1Api()
+        v1 = client.RbacAuthorizationV1Api()
+
+        # Create service account role binding with admin access for airflow worker
+        role_binding_name_worker = "full-access-user-clusterrolebinding-worker"
+        sa_name = "flowui-airflow-worker"
+        cluster_role_binding_worker = client.V1ClusterRoleBinding(
+            metadata=client.V1ObjectMeta(name=role_binding_name_worker),
+            subjects=[
+                client.V1Subject(
+                    kind="ServiceAccount",
+                    name=sa_name,
+                    namespace="default"
+                )
+            ],
+            role_ref=client.V1RoleRef(
+                kind="ClusterRole",
+                name="cluster-admin",
+                api_group="rbac.authorization.k8s.io"
+            )
+        )
+        console.print('Creating RBAC Worker Authorization for local dev')
+        v1.create_cluster_role_binding(cluster_role_binding_worker)
+
+        role_binding_name_scheduler = "full-access-user-clusterrolebinding-scheduler"
+        sa_name = "flowui-airflow-scheduler"
+        cluster_role_binding_scheduler = client.V1ClusterRoleBinding(
+            metadata=client.V1ObjectMeta(name=role_binding_name_scheduler),
+            subjects=[
+                client.V1Subject(
+                    kind="ServiceAccount",
+                    name=sa_name,
+                    namespace="default"
+                )
+            ],
+            role_ref=client.V1RoleRef(
+                kind="ClusterRole",
+                name="cluster-admin",
+                api_group="rbac.authorization.k8s.io"
+            )
+        )
+        console.print('Creating RBAC Scheduler Authorization for local dev')
+        v1.create_cluster_role_binding(cluster_role_binding_scheduler)
+
         for project_name in flowui_config["local_operators_repositories"].keys():
+            console.log(f"Creating PV and PVC for {project_name}...")
             # Check if pv already exists
             persistent_volume_name = 'pv-{}'.format(str(project_name.lower().replace('_', '-')))
             persistent_volume_claim_name = 'pvc-{}'.format(str(project_name.lower().replace('_', '-')))
@@ -371,7 +418,8 @@ def create_platform(flowui_frontend_image: str = None, flowui_backend_image: str
                     )
                 )
                 k8s_client.create_namespaced_persistent_volume_claim(namespace="default", body=pvc)
-                pv_exists = False
+
+            pv_exists = False
             try:
                 k8s_client.read_persistent_volume(name=persistent_volume_name)
                 pv_exists = True
@@ -412,8 +460,8 @@ def create_platform(flowui_frontend_image: str = None, flowui_backend_image: str
                 )
                 k8s_client.create_persistent_volume(body=pv)
         
-        if flowui_config['local_flowui_repository']['FLOWUI_LOCAL_FLOWUI_REPOSITORY']:
-            console.print("Creating PV's and PVC's for Local FlowUI Development mode...")
+        if flowui_config['local_flowui_repository'].get('FLOWUI_LOCAL_FLOWUI_REPOSITORY'):
+            console.print("Creating PV's and PVC's for Local FlowUI Package...")
             # Create pv and pvc for local dev flowui
             pvc = client.V1PersistentVolumeClaim(
                 metadata=client.V1ObjectMeta(name="flowui-dev-volume-claim"),
